@@ -1,4 +1,4 @@
-from .core import AbstractSAS
+from .sas.core import AbstractSAS
 from .globals import sasma_sasobjsp_host, sasma_sasobjsp_port, sasma_workspace
 
 
